@@ -2,6 +2,6 @@ var pgsql__host__data__source_8h =
 [
     [ "isc::dhcp::PgSqlHostDataSource::PgSqlHostContextAlloc", "d1/d63/classisc_1_1dhcp_1_1PgSqlHostDataSource_1_1PgSqlHostContextAlloc.html", "d1/d63/classisc_1_1dhcp_1_1PgSqlHostDataSource_1_1PgSqlHostContextAlloc" ],
     [ "isc::dhcp::PgSqlHostDataSource", "d4/de3/classisc_1_1dhcp_1_1PgSqlHostDataSource.html", "d4/de3/classisc_1_1dhcp_1_1PgSqlHostDataSource" ],
-    [ "PgSqlHostContextPtr", "d1/db5/pgsql__host__data__source_8h.html#a1d3d9865fcc851d1a16315e5bda4ae92", null ],
-    [ "PgSqlHostDataSourceImplPtr", "d1/db5/pgsql__host__data__source_8h.html#af8e0ca58a08bf4828f7ec81da27f6c0e", null ]
+    [ "isc::dhcp::PgSqlHostContextPtr", "d5/d8c/namespaceisc_1_1dhcp.html#a1d3d9865fcc851d1a16315e5bda4ae92", null ],
+    [ "isc::dhcp::PgSqlHostDataSourceImplPtr", "d5/d8c/namespaceisc_1_1dhcp.html#af8e0ca58a08bf4828f7ec81da27f6c0e", null ]
 ];
\ No newline at end of file
