@@ -1,29 +1,49 @@
 var index =
 [
     [ "Contributor's Guide", "index.html#contrib", null ],
-    [ "Building Kea with Unit tests", "index.html#buildingKeaWithUnitTests", null ],
-    [ "Performance", "index.html#performance", null ],
+    [ "Quality Assurance", "index.html#qa", null ],
     [ "Hooks Framework", "index.html#hooksFramework", null ],
     [ "DHCP Maintenance Guide", "index.html#dhcpMaintenanceGuide", null ],
     [ "Kea libraries", "index.html#libraries", null ],
     [ "Miscellaneous Topics", "index.html#miscellaneousTopics", null ],
     [ "Kea Contributor's Guide", "d7/df4/contributorGuide.html", null ],
+    [ "Quality Assurance in Kea", "d6/d4f/qaIntro.html", [
+      [ "Running CI pipeline on Github", "d6/d4f/qaIntro.html#ciGithub", null ],
+      [ "Running CI pipeline on Gitlab", "d6/d4f/qaIntro.html#ciGitlab", null ],
+      [ "Running CI pipeline on Jenkins", "d6/d4f/qaIntro.html#ciJenkins", null ]
+    ] ],
     [ "Building Kea with Unit Tests", "d1/d2e/unitTests.html", [
       [ "Environment Variables", "d1/d2e/unitTests.html#unitTestsEnvironmentVariables", null ],
       [ "Use Sanitizers", "d1/d2e/unitTests.html#unitTestsSanitizers", null ],
       [ "Databases Configuration for Unit Tests", "d1/d2e/unitTests.html#unitTestsDatabaseConfig", [
         [ "Database Users Required for Unit Tests", "d1/d2e/unitTests.html#unitTestsDatabaseUsers", null ],
         [ "MySQL Database", "d1/d2e/unitTests.html#mysqlUnitTestsPrerequisites", null ],
-        [ "PostgreSQL Database", "d1/d2e/unitTests.html#pgsqlUnitTestsPrerequisites", null ],
-        [ "Cassandra database", "d1/d2e/unitTests.html#cqlUnitTestsPrerequisites", null ]
+        [ "MySQL Database with SSL/TLS", "d1/d2e/unitTests.html#mysqlUnitTestsTLS", null ],
+        [ "PostgreSQL Database", "d1/d2e/unitTests.html#pgsqlUnitTestsPrerequisites", null ]
       ] ],
+      [ "Kerberos Configuration for Unit Tests", "d1/d2e/unitTests.html#unitTestsKerberos", null ],
       [ "Writing shell scripts and tests", "d1/d2e/unitTests.html#writingShellScriptsAndTests", null ]
     ] ],
-    [ "Benchmarks: Measuring performance", "d8/de4/benchmarks.html", [
-      [ "benchmarksOverview", "d8/de4/benchmarks.html#benchmarksOverview", null ],
-      [ "Internal code organization", "d8/de4/benchmarks.html#benchmarksCode", null ],
-      [ "Explaining control flow in benchmarks", "d8/de4/benchmarks.html#benchmarkControlFlow", null ],
-      [ "Adding new benchmarks", "d8/de4/benchmarks.html#benchmarkNew", null ]
+    [ "Performance Testing", "dc/d3c/performance.html", "dc/d3c/performance" ],
+    [ "Fuzzing Kea", "d9/d8b/fuzzer.html", [
+      [ "Introduction", "d9/d8b/fuzzer.html#fuzzIntro", null ],
+      [ "Types of Kea Fuzzing", "d9/d8b/fuzzer.html#fuzzTypes", [
+        [ "Fuzzing with Network Packets", "d9/d8b/fuzzer.html#fuzzTypeNetwork", null ],
+        [ "Fuzzing with Configuration Files", "d9/d8b/fuzzer.html#fuzzTypeConfig", null ]
+      ] ],
+      [ "Building Kea for Fuzzing", "d9/d8b/fuzzer.html#fuzzBuild", null ],
+      [ "Running the Fuzzer", "d9/d8b/fuzzer.html#fuzzRun", [
+        [ "Fuzzing with Network Packets", "d9/d8b/fuzzer.html#fuzzRunNetwork", null ],
+        [ "Fuzzing with Configuration Files", "d9/d8b/fuzzer.html#fuzzRunConfig", null ]
+      ] ],
+      [ "Internals", "d9/d8b/fuzzer.html#Fuzzing", [
+        [ "Fuzzing with Network Packets", "d9/d8b/fuzzer.html#fuzzInternalNetwork", null ],
+        [ "Fuzzing with Configuration Files", "d9/d8b/fuzzer.html#fuzzInternalConfig", null ],
+        [ "Changes Required for Multi-Threaded Kea", "d9/d8b/fuzzer.html#fuzzThreads", null ]
+      ] ],
+      [ "Notes", "d9/d8b/fuzzer.html#fuzzNotes", [
+        [ "Unit Test Failures", "d9/d8b/fuzzer.html#fuzzNotesUnitTests", null ]
+      ] ]
     ] ],
     [ "Hooks Developer's Guide", "df/d46/hooksdgDevelopersGuide.html", [
       [ "Introduction", "df/d46/hooksdgDevelopersGuide.html#hooksdgIntroduction", [
@@ -77,7 +97,10 @@ var index =
         [ "lease4_renew", "de/df3/dhcpv4Hooks.html#dhcpv4HooksLeaseRenew", null ],
         [ "lease4_release", "de/df3/dhcpv4Hooks.html#dhcpv4HooksLeaseRelease", null ],
         [ "lease4_decline", "de/df3/dhcpv4Hooks.html#dhcpv4HooksLeaseDecline", null ],
+        [ "ddns4_update", "de/df3/dhcpv4Hooks.html#dhcpv4HooksDdns4Update", null ],
         [ "leases4_committed", "de/df3/dhcpv4Hooks.html#dhcpv4Leases4Committed", null ],
+        [ "lease4_offer", "de/df3/dhcpv4Hooks.html#dhcpv4Lease4Offer", null ],
+        [ "lease4_server_decline", "de/df3/dhcpv4Hooks.html#dhcpv4Lease4ServerDecline", null ],
         [ "pkt4_send", "de/df3/dhcpv4Hooks.html#dhcpv4HooksPkt4Send", null ],
         [ "buffer4_send", "de/df3/dhcpv4Hooks.html#dhcpv4HooksBuffer4Send", null ],
         [ "lease4_expire", "de/df3/dhcpv4Hooks.html#dhcpv4HooksLease4Expire", null ],
@@ -100,6 +123,7 @@ var index =
         [ "lease6_rebind", "d1/d02/dhcpv6Hooks.html#dhcpv6HooksLease6Rebind", null ],
         [ "lease6_decline", "d1/d02/dhcpv6Hooks.html#dhcpv6HooksLease6Decline", null ],
         [ "lease6_release", "d1/d02/dhcpv6Hooks.html#dhcpv6HooksLease6Release", null ],
+        [ "ddns6_update", "d1/d02/dhcpv6Hooks.html#dhcpv6HooksDdns6Update", null ],
         [ "leases6_committed", "d1/d02/dhcpv6Hooks.html#dhcpv6Leases6Committed", null ],
         [ "pkt6_send", "d1/d02/dhcpv6Hooks.html#dhcpv6HooksPkt6Send", null ],
         [ "buffer6_send", "d1/d02/dhcpv6Hooks.html#dhcpv6HooksBuffer6Send", null ],
@@ -114,7 +138,8 @@ var index =
       [ "Hooks in the Control Agent", "d4/d6b/agentHooks.html#agentHooksHookPoints", [
         [ "auth", "d4/d6b/agentHooks.html#agentHooksAuth", null ],
         [ "response", "d4/d6b/agentHooks.html#agentHooksResponse", null ]
-      ] ]
+      ] ],
+      [ "Handle and hook unload", "d4/d6b/agentHooks.html#agentHooksHandle", null ]
     ] ],
     [ "The Hooks API for the Kea DHCP DDNS (D2)", "d4/d7d/d2Hooks.html", [
       [ "Introduction", "d4/d7d/d2Hooks.html#d2HooksIntroduction", null ],
@@ -270,7 +295,6 @@ var index =
       [ "Instantiation of Lease Managers", "d6/dbd/dhcpDatabaseBackends.html#dhcpdb-instantiation", [
         [ "MySQL connection string keywords", "d6/dbd/dhcpDatabaseBackends.html#dhcpdb-keywords-mysql", null ],
         [ "PostgreSQL connection string keywords", "d6/dbd/dhcpDatabaseBackends.html#dhcpdb-keywords-pgsql", null ],
-        [ "Cassandra (CQL) connection string keywords", "d6/dbd/dhcpDatabaseBackends.html#dhcpdb-keywords-cql", null ],
         [ "Infinite Valid Lifetime", "d6/dbd/dhcpDatabaseBackends.html#infinite-valid-lifetime", null ]
       ] ],
       [ "Host Backends", "d6/dbd/dhcpDatabaseBackends.html#dhcpdb-host", [
@@ -283,16 +307,6 @@ var index =
       [ "Alternate Configuration Backends", "d7/dc5/configBackend.html#configBackendHistoric", null ],
       [ "The JSON Configuration Backend", "d7/dc5/configBackend.html#configBackendJSONDesign", null ]
     ] ],
-    [ "perfdhcp Internals", "d6/de6/perfdhcpInternals.html", [
-      [ "perfdhcp Classes", "d6/de6/perfdhcpInternals.html#perfdhcpClasses", [
-        [ "CommandOptions (Command Options)", "d6/de6/perfdhcpInternals.html#perfdhcpCommandOptions", null ],
-        [ "TestControl (Test Control)", "d6/de6/perfdhcpInternals.html#perfdhcpTestControl", null ],
-        [ "StatsMgr (Statistics Manager)", "d6/de6/perfdhcpInternals.html#perfStatsMgr", null ],
-        [ "PerfPkt4 and PerfPkt6", "d6/de6/perfdhcpInternals.html#perfdhcpPkt", null ],
-        [ "LocalizedOption (Localized Option)", "d6/de6/perfdhcpInternals.html#perfdhcpLocalizedOption", null ],
-        [ "PktTransform (Packet Transform)", "d6/de6/perfdhcpInternals.html#perfdhcpPktTransform", null ]
-      ] ]
-    ] ],
     [ "libkea-util - Kea Utilities Library", "dd/dd6/libutil.html", [
       [ "Utilities", "dd/dd6/libutil.html#utilUtilities", null ],
       [ "Multi-Threading Consideration for Utilities", "dd/dd6/libutil.html#utilMTConsiderations", null ]
@@ -330,6 +344,7 @@ var index =
       [ "Multi-Threading Consideration for DHCP_DDNS Request I/O Library", "d2/d9a/libdhcp_ddns.html#libdhcp_ddnsMTConsiderations", null ]
     ] ],
     [ "libkea-dhcpsrv - Server DHCP Library", "d8/d5f/libdhcpsrv.html", [
+      [ "Global Parameters", "d8/d5f/libdhcpsrv.html#cfgglobals", null ],
       [ "Lease Manager", "d8/d5f/libdhcpsrv.html#leasemgr", null ],
       [ "Configuration Manager", "d8/d5f/libdhcpsrv.html#cfgmgr", null ],
       [ "Host Manager", "d8/d5f/libdhcpsrv.html#hostmgr", [
@@ -420,27 +435,6 @@ var index =
       [ "Logging Messages", "dd/d70/LoggingApi.html#LoggingApiLoggingMessages", null ],
       [ "Implementation Issues", "dd/d70/LoggingApi.html#LoggingApiImplementationIssues", null ]
     ] ],
-    [ "Socket session utility", "dc/d78/SocketSessionUtility.html", null ],
-    [ "Fuzzing Kea", "d9/d8b/fuzzer.html", [
-      [ "Introduction", "d9/d8b/fuzzer.html#fuzzIntro", null ],
-      [ "Types of Kea Fuzzing", "d9/d8b/fuzzer.html#fuzzTypes", [
-        [ "Fuzzing with Network Packets", "d9/d8b/fuzzer.html#fuzzTypeNetwork", null ],
-        [ "Fuzzing with Configuration Files", "d9/d8b/fuzzer.html#fuzzTypeConfig", null ]
-      ] ],
-      [ "Building Kea for Fuzzing", "d9/d8b/fuzzer.html#fuzzBuild", null ],
-      [ "Running the Fuzzer", "d9/d8b/fuzzer.html#fuzzRun", [
-        [ "Fuzzing with Network Packets", "d9/d8b/fuzzer.html#fuzzRunNetwork", null ],
-        [ "Fuzzing with Configuration Files", "d9/d8b/fuzzer.html#fuzzRunConfig", null ]
-      ] ],
-      [ "Internals", "d9/d8b/fuzzer.html#Fuzzing", [
-        [ "Fuzzing with Network Packets", "d9/d8b/fuzzer.html#fuzzInternalNetwork", null ],
-        [ "Fuzzing with Configuration Files", "d9/d8b/fuzzer.html#fuzzInternalConfig", null ],
-        [ "Changes Required for Multi-Threaded Kea", "d9/d8b/fuzzer.html#fuzzThreads", null ]
-      ] ],
-      [ "Notes", "d9/d8b/fuzzer.html#fuzzNotes", [
-        [ "Unit Test Failures", "d9/d8b/fuzzer.html#fuzzNotesUnitTests", null ]
-      ] ]
-    ] ],
     [ "Kea Cross-Compiling Example", "de/d9a/crossCompile.html", [
       [ "Cross-Compile Tool Chain", "de/d9a/crossCompile.html#toolChain", null ],
       [ "How to get system and packages without a running Raspberry Pi", "de/d9a/crossCompile.html#noRaspberry", null ],
@@ -448,6 +442,9 @@ var index =
       [ "Usual Kea Dependencies", "de/d9a/crossCompile.html#raspbianDependencies", null ],
       [ "Prepare Cross Compiling", "de/d9a/crossCompile.html#prepareCrossCompile", null ]
     ] ],
+    [ "Debugging Kea", "db/d4d/debug.html", [
+      [ "Enabling debug symbols", "db/d4d/debug.html#debugSymbols", null ]
+    ] ],
     [ "Building Kea Documentation", "d2/d86/docs.html", [
       [ "Documenting new command", "d2/d86/docs.html#docsNewCommand", null ],
       [ "Generating Developer's Guide", "d2/d86/docs.html#docsDevelGuide", null ]
